OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "No se puede escribir en la carpeta \"config\"!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Normalmente esto se puede arreglar dando al servidor web acceso de escritura a la carpeta config.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Pero, si prefieres mantener el archivo config.php como solo de lectura, establece la opción \"config_is_read_only\" a true en él.",
    "See %s" : "Ver %s",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Los archivos de la app %1$s no se han reemplazado correctamente. Asegúrate de que es una versión compatible con el servidor.",
    "Sample configuration detected" : "Configuración de ejemplo detectada",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Se ha detectado que el ejemplo de configuración ha sido copiado. Esto podría afectar a su instalación, por lo que no tiene soporte. Lea la documentación antes de hacer cambios en config.php",
    "%s email verification" : "%s verificación del correo electrónico",
    "Email verification" : "Verificación del correo electrónico",
    "Click the following button to confirm your email." : "Haz clic en el siguiente botón para confirmar tu correo electrónico.",
    "Click the following link to confirm your email." : "Haz clic en el siguiente enlace para confirmar tu correo electrónico.",
    "Confirm your email" : "Confirma tu correo electrónico",
    "Other activities" : "Otras actividades",
    "%1$s and %2$s" : "%1$s y %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s y %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s, y %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s y %5$s",
    "Education Edition" : "Edición Educación",
    "Enterprise bundle" : "Pack para empresas",
    "Groupware bundle" : "Pack groupware",
    "Hub bundle" : "Pack para Hub",
    "Social sharing bundle" : "Pack para compartir en redes",
    "PHP %s or higher is required." : "Se requiere PHP %s o superior.",
    "PHP with a version lower than %s is required." : "Se necesita una versión de PHP inferior a %s",
    "%sbit or higher PHP required." : "Se requiere PHP %sbit o superior.",
    "The following architectures are supported: %s" : "Las siguientes arquitecturas están soportadas: %s",
    "The following databases are supported: %s" : "Las siguientes bases de datos están soportadas: %s",
    "The command line tool %s could not be found" : "No se encontró la herramienta %s de línea de comandos",
    "The library %s is not available." : "La biblioteca %s no está disponible",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Se requiere la biblioteca %1$s con una versión mayor que %2$s. Está disponible la versión %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Se requiera la biblioteca %1$s con una versión menor que %2$s. Está disponible la versión %3$s.",
    "The following platforms are supported: %s" : "Las siguientes plataformas están soportadas: %s",
    "Server version %s or higher is required." : "Se necesita la versión %s o superior del servidor.",
    "Server version %s or lower is required." : "Se necesita la versión %s o inferior del servidor.  ",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "La sesión del usuario debe corresponder a un administrador, subadministrador, o debe tener derechos especiales para acceder a esta configuración.",
    "Logged in user must be an admin or sub admin" : "El usuario activo debe ser un administrador o subadministrador",
    "Logged in user must be an admin" : "El usuario registrado debe ser un administrador",
    "Wiping of device %s has started" : "El borrado del dispositivo %s ha empezado",
    "Wiping of device »%s« has started" : "El borrado del dispositivo »%s« ha empezado",
    "»%s« started remote wipe" : "»%s« ha empezado el borrado a distancia",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "El dispositivo o la aplicación »%s« ha empezado el proceso de borrado a distancia. Vas a recibir otro mensaje por correo una vez que el proceso haya concluido.",
    "Wiping of device %s has finished" : "El borrado del dispositivo %s ha concluido",
    "Wiping of device »%s« has finished" : "El borrado del dispositivo »%s« ha concluido",
    "»%s« finished remote wipe" : "»%s« ha acabado el borrado a distancia",
    "Device or application »%s« has finished the remote wipe process." : "El dispositivo o la aplicación »%s« ha concluido el proceso de borrado a distancia.",
    "Remote wipe started" : "Borrado remoto comenzado.",
    "A remote wipe was started on device %s" : "Se ha iniciado un borrado remoto en el dispositivo %s.",
    "Remote wipe finished" : "Borrado remoto finalizado",
    "The remote wipe on %s has finished" : "El borrado remoto en %s ha finalizado",
    "Authentication" : "Autentificación",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen no válida",
    "Avatar image is not square" : "La imagen de avatar no es cuadrada",
    "View profile" : "Ver perfil",
    "today" : "hoy",
    "tomorrow" : "mañana",
    "yesterday" : "ayer",
    "_in %n day_::_in %n days_" : ["dentro de %n día","dentro de %n días","dentro de %n días"],
    "_%n day ago_::_%n days ago_" : ["Hace %n día","hace %n días","hace %n días"],
    "next month" : "mes siguiente",
    "last month" : "mes pasado",
    "_in %n month_::_in %n months_" : ["dentro de %n mes","dentro de %n meses","dentro de %n meses"],
    "_%n month ago_::_%n months ago_" : ["Hace %n mes","hace %n meses","hace %n meses"],
    "next year" : "año que viene",
    "last year" : "año pasado",
    "_in %n year_::_in %n years_" : ["dentro de %n año","dentro de %n años","dentro de %n años"],
    "_%n year ago_::_%n years ago_" : ["Hace %n año","hace %n años","hace %n años"],
    "_in %n hour_::_in %n hours_" : ["dentro de %n hora","dentro de %n horas","dentro de %n horas"],
    "_%n hour ago_::_%n hours ago_" : ["Hace %n hora","hace %n horas","hace %n horas"],
    "_in %n minute_::_in %n minutes_" : ["dentro de %n minuto","dentro de %n minutos","dentro de %n minutos"],
    "_%n minute ago_::_%n minutes ago_" : ["Hace %n minuto","hace %n minutos","hace %n minutos"],
    "in a few seconds" : "en unos segundos",
    "seconds ago" : "hace segundos",
    "Empty file" : "Archivo vacío",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "El módulo con ID %s no existe. Por favor, actívalo en la configuración de apps o contacta con tu administrador.",
    "File already exists" : "El archivo ya existe",
    "Invalid path" : "Ruta no válida",
    "Failed to create file from template" : "Fallo al crear el archivo desde plantilla",
    "Templates" : "Plantillas",
    "File name is a reserved word" : "El nombre de archivo es una palabra reservada",
    "File name contains at least one invalid character" : "El nombre del archivo contiene al menos un carácter inválido",
    "File name is too long" : "El nombre del archivo es demasiado largo",
    "Dot files are not allowed" : "Los archivos Dot no están permitidos",
    "Empty filename is not allowed" : "No se puede dejar el nombre en blanco.",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "No se puede instalar la app \"%s\" debido a que no se puede leer la información de la app.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "No se puede instalar la aplicación \"%s\" porque no es compatible con esta versión del servidor.",
    "__language_name__" : "Español (España)",
    "This is an automatically sent email, please do not reply." : "Este es un correo enviado automáticamente, por favor no responda.",
    "Help" : "Ayuda",
    "Apps" : "Aplicaciones",
    "Personal settings" : "Ajustes personales",
    "Settings" : "Ajustes",
    "Log out" : "Cerrar sesión",
    "Users" : "Usuarios",
    "Email" : "Correo electrónico",
    "Mail %s" : "Correo %s",
    "Phone" : "Teléfono",
    "Call %s" : "Llamada %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Ver %s en Twitter",
    "Website" : "Sitio web",
    "Visit %s" : "Visita %s",
    "Address" : "Dirección",
    "Profile picture" : "Imagen de perfil",
    "About" : "Acerca de",
    "Full name" : "Nombre completo",
    "Headline" : "Titular",
    "Organisation" : "Organización",
    "Role" : "Puesto",
    "Unknown user" : "Usuario desconocido",
    "Additional settings" : "Configuración adicional",
    "%s enter the database username and name." : "%s introduzca el nombre de usuario y la contraseña de la BBDD.",
    "%s enter the database username." : "%s introduzca el usuario de la base de datos.",
    "%s enter the database name." : "%s introduzca el nombre de la base de datos",
    "%s you may not use dots in the database name" : "%s puede utilizar puntos en el nombre de la base de datos",
    "MySQL username and/or password not valid" : "Usuario y/o contraseña de MySQL no válidos",
    "You need to enter details of an existing account." : "Tienes que introducir los datos de una cuenta existente.",
    "Oracle connection could not be established" : "No se pudo establecer la conexión a Oracle",
    "Oracle username and/or password not valid" : "Usuario y/o contraseña de Oracle no válidos",
    "PostgreSQL username and/or password not valid" : "Usuario y/o contraseña de PostgreSQL no válidos",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X no está soportado y %s no funcionará bien en esta plataforma. ¡Úsala bajo tu propio riesgo! ",
    "For the best results, please consider using a GNU/Linux server instead." : "Para obtener los mejores resultados, considera utilizar un servidor GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Parece que esta instancia %s está funcionando en un entorno PHP de 32-bits y el open_basedir se ha configurado en php.ini. Esto acarreará problemas con archivos de tamaño superior a 4GB y resulta totalmente desaconsejado.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor, quite el ajuste de open_basedir —dentro de su php.ini— o pásese a PHP de 64 bits.",
    "Set an admin username." : "Configurar un nombre de usuario del administrador",
    "Set an admin password." : "Configurar la contraseña del administrador.",
    "Cannot create or write into the data directory %s" : "No se puede crear o escribir en la carpeta de datos %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El motor compartido %s debe implementar la interfaz OCP\\Share_Backend",
    "Sharing backend %s not found" : "El motor compartido %s no se ha encontrado",
    "Sharing backend for %s not found" : "Motor compartido para %s no encontrado",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s ha compartido «%2$s» contigo y quiere añadir:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s ha compartido «%2$s» contigo y quiere añadir",
    "»%s« added a note to a file shared with you" : "«%s» ha añadido una nota a un archivo compartido contigo",
    "Open »%s«" : "Abrir »%s« ",
    "%1$s via %2$s" : "%1$s vía %2$s",
    "You are not allowed to share %s" : "Usted no está autorizado para compartir %s",
    "Cannot increase permissions of %s" : "No se pueden incrementar los permisos de %s",
    "Files cannot be shared with delete permissions" : "Los archivos no se pueden compartir con permisos de borrado",
    "Files cannot be shared with create permissions" : "Los archivos no se pueden compartir con permisos de creación",
    "Expiration date is in the past" : "Ha pasado la fecha de caducidad",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["No se puede fijar la fecha de caducidad más de %n día en el futuro.","No se puede fijar la fecha de caducidad más de %n días en el futuro.","No se puede fijar la fecha de caducidad más de %n días en el futuro."],
    "Sharing is only allowed with group members" : "Sólo está permitido compartir a los integrantes del grupo",
    "Sharing %s failed, because this item is already shared with user %s" : "No se pudo compartir %s, porque este elemento ya está compartido con el usuario %s",
    "%1$s shared »%2$s« with you" : "%1$s ha compartido «%2$s» contigo",
    "%1$s shared »%2$s« with you." : "%1$s ha compartido «%2$s» contigo.",
    "Click the button below to open it." : "Haz clic en el botón de abajo para abrirlo.",
    "The requested share does not exist anymore" : "El recurso compartido solicitado ya no existe",
    "Could not find category \"%s\"" : "No puede encontrar la categoría \"%s\"",
    "Sunday" : "Domingo",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sun." : "Dom.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mié.",
    "Thu." : "Jue.",
    "Fri." : "Vie.",
    "Sat." : "Sáb.",
    "Su" : "Do",
    "Mo" : "Lu",
    "Tu" : "Ma",
    "We" : "Mi",
    "Th" : "Ju",
    "Fr" : "Vi",
    "Sa" : "Sa",
    "January" : "enero",
    "February" : "febrero",
    "March" : "marzo",
    "April" : "abril",
    "May" : "mayo",
    "June" : "junio",
    "July" : "julio",
    "August" : "agosto",
    "September" : "septiembre",
    "October" : "octubre",
    "November" : "noviembre",
    "December" : "diciembre",
    "Jan." : "Ene.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "May.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Ago.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Dic.",
    "The user limit has been reached and the user was not created." : "Ha sido alcanzado el límite de usuarios, por tanto el usuario no fue creado.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Solo los siguientes caracteres están permitidos en un nombre de usuario: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
    "A valid username must be provided" : "Se debe proporcionar un nombre de usuario válido",
    "Username contains whitespace at the beginning or at the end" : "El nombre de usuario contiene espacios en blanco al principio o al final",
    "Username must not consist of dots only" : "El nombre de usuario no debe consistir solo de puntos",
    "Username is invalid because files already exist for this user" : "El nombre de usuario es incorrecto debido a a que los archivos ya existen para este usuario",
    "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
    "The username is already being used" : "El nombre de usuario ya está en uso",
    "Could not create user" : "No se ha podido crear el usuario",
    "User disabled" : "Usuario deshabilitado",
    "Login canceled by app" : "Login cancelado por la app",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "No se ha podido instlaar la app «%1$s» porque no se cumplen las siguientes dependencias: %2$s",
    "a safe home for all your data" : "un hogar seguro para todos tus datos",
    "File is currently busy, please try again later" : "El archivo se encuentra actualmente ocupado, por favor inténtelo de nuevo más tarde",
    "Application is not enabled" : "La aplicación no está habilitada",
    "Authentication error" : "Error de autenticación",
    "Token expired. Please reload page." : "Token caducado. Por favor, recarge la página.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "No están instalados los drivers de BBDD  (sqlite, mysql, o postgresql)",
    "Cannot write into \"config\" directory." : "No se puede escribir en la carpeta «config».",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Normalmente esteo se puede arreglar dando al servidor web acceso de escritura a la carpeta config. Véase %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "O, si prefieres mantener el archivo config.php como de solo lectura, marca la opción \"config_is_read_only\" a 'true' en él. Ver %s",
    "Cannot write into \"apps\" directory." : "No se puede escribir en la carpeta «apps».",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Normalmente esto se puede arreglar dando al servidor web acceso de escritura a la carpeta de apps o desactivando la App Store en el archivo de configuración.",
    "Cannot create \"data\" directory." : "No se puede crear la carpeta \"data\"",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Normalmente esto se puede arreglar dando al servidor web acceso de escritura a la carpeta raíz. Véase %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Los permisos normalmente se pueden arreglar dando al servidor web acceso de escritura a la carpeta raíz. Véase %s",
    "Your data directory is not writable." : "No se puede escribir en tu carpeta de datos.",
    "Setting locale to %s failed." : "Fallo al configurar el idioma a %s.",
    "Please install one of these locales on your system and restart your web server." : "Por favor, instala uno de estos idiomas en tu sistema y reinicia tu servidor web.",
    "PHP module %s not installed." : "El módulo PHP %s no está instalado.",
    "Please ask your server administrator to install the module." : "Consulte al administrador de su servidor para instalar el módulo.",
    "PHP setting \"%s\" is not set to \"%s\"." : "La opción PHP \"%s\" no es \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Ajustar esta configuración en php.ini hará que Nextcloud funcione de nuevo",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> está establecida como <code>%s</code> en lugar del valor esperado: <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Para arreglar este problema, establece <code>mbstring.func_overload</code> en<code>0</code> en tu php.ini.",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 es requerido en esta o en versiones superiores. Ahora mismo tienes instalada %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Para corregir este error, actualiza la versión de tu libxml2 y reinicia el servidor web.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP está aparentemente configurado para eliminar bloques de documentos en línea. Esto hará que varias aplicaciones principales estén inaccesibles.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Probablemente esto venga a causa de la caché o un acelerador, tales como Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Los módulos PHP se han instalado, pero aparecen listados como si faltaran",
    "Please ask your server administrator to restart the web server." : "Consulte al administrador de su servidor para reiniciar el servidor web.",
    "The required %s config variable is not configured in the config.php file." : "La variable de configuración %s requerida no está configurada en el archivo config.php.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Por favor, pida al administrador de su servidor que compruebe la configuración de Nextcloud.",
    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 requerido.",
    "Please upgrade your database version." : "Por favor, actualiza la versión de tu base de datos.",
    "Your data directory is readable by other users." : "Tu carpeta de datos puede ser leído por otros usuarios.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor, cambia los permisos a 0770 para que el directorio no se pueda mostrar a otros usuarios.",
    "Your data directory must be an absolute path." : "Tu carpeta de datos debe ser una ruta absoluta.",
    "Check the value of \"datadirectory\" in your configuration." : "Comprueba el valor de «datadirectory» en tu configuración.",
    "Your data directory is invalid." : "Tu carpeta de datos es inválida.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Asegúrate de que existe un archivo llamado \".ocdata\" en la raíz del directorio de datos.",
    "Action \"%s\" not supported or implemented." : "La acción \"%s\" no está soportada o implementada.",
    "Authentication failed, wrong token or provider ID given" : "La autentificación ha fallado. Se ha dado un token o una ID de proveedor erróneos.",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Faltan parámetros para completar la petición. Parámetros que faltan: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "La ID  «%1$s» ya está siendo usada por el proveedor de federación en la nube  «%2$s»",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "El proveedor de nube federada con ID \"%s\" no existe.",
    "Could not obtain lock type %d on \"%s\"." : "No se pudo realizar el bloqueo %d en \"%s\".",
    "Storage unauthorized. %s" : "Almacenamiento no autorizado. %s",
    "Storage incomplete configuration. %s" : "Configuración de almacenamiento incompleta. %s",
    "Storage connection error. %s" : "Error de conexión de almacenamiento. %s",
    "Storage is temporarily not available" : "El almacenamiento no esta disponible temporalmente",
    "Storage connection timeout. %s" : "Tiempo de conexión de almacenamiento agotado. %s",
    "This can usually be fixed by giving the webserver write access to the config directory." : "Se podría solucionar esto dándole al servidor permisos de escritura del directorio de configuración.",
    "Cannot read file" : "No se puede leer archivo",
    "Cannot write into \"config\" directory" : "No se puede escribir el el directorio de configuración",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Se podría solucionar esto dándole al servidor permisos de escritura del directorio de configuración. Ver %s",
    "Cannot write into \"apps\" directory" : "No se puede escribir en el directorio de \"apps\"",
    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Se podría solucionar esto dando al servidor web acceso de escritura a la carpeta de apps o desactivando la tienda de apps en el archivo de configuración.",
    "Cannot create \"data\" directory" : "No se puede crear el directorio \"data\"",
    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Habitualmente, esto puede arreglarse dando al servidor web acceso de escritura al directorio raíz. Véase %s",
    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Habitualmente, los permisos pueden arreglarse dando al servidor web acceso de escritura al directorio raíz. Véase %s",
    "Setting locale to %s failed" : "Ha fallado la activación de la localización %s ",
    "Please install one of these locales on your system and restart your webserver." : "Instale uno de estos idiomas en su sistema y reinicie su servidor web.",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload está dispuesta en \"%s\" en lugar del valor esperado \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Para solucionarlo, defina la función <code>mbstring.func_overload</code> a <code>0</code> en su php.ini",
    "PostgreSQL >= 9 required" : "PostgreSQL 9 o superior requerido.",
    "Please upgrade your database version" : "Actualice su versión de base de datos.",
    "Your data directory is readable by other users" : "Tu directorio de datos puede ser leído por otros usuarios",
    "Your data directory must be an absolute path" : "Su directorio data debe ser una ruta absoluta",
    "Check the value of \"datadirectory\" in your configuration" : "Compruebe el valor de \"datadirectory\" en su configuración.",
    "Your data directory is invalid" : "Tu directorio de datos es inválido"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
